@@ -14,7 +14,7 @@
 #' grid/network to Power, general mining to coal mining).
 #'
 #' For a list of sector classification systems see
-#' [r2dii.data::classification_bridge].
+#' [r2dii.data::sector_classifications].
 #'
 #' @param data A loanbook data frame.
 #'
@@ -60,21 +60,21 @@ check_classification <- function(data,
   all_unknown <- !any(data[[column]] %in% reference[[column]])
   known <- unique(reference[[column]])
   if (all_unknown) {
-    abort_all_sector_classification_is_unknown(column, known)
+    abort_all_sec_classif_unknown(column, known)
   }
 
   unknown <- setdiff(unique(data[[column]]), reference[[column]])
   some_unknown <- !identical(unknown, character(0))
   if (some_unknown) {
-    warn_some_sector_classification_is_unknown(column, unknown)
+    warn_some_sec_classif_unknown(column, unknown)
   }
 
   invisible(data)
 }
 
-abort_all_sector_classification_is_unknown <- function(column, known) {
+abort_all_sec_classif_unknown <- function(column, known) {
   abort(
-    class = "all_sector_classification_is_unknown",
+    class = "all_sec_classif_unknown",
     message = glue(
       "Some `{column}` must be known, i.e. one of:
       {collapse2(known)}"
@@ -82,9 +82,9 @@ abort_all_sector_classification_is_unknown <- function(column, known) {
   )
 }
 
-warn_some_sector_classification_is_unknown <- function(column, unknown) {
+warn_some_sec_classif_unknown <- function(column, unknown) {
   warn(
-    class = "some_sector_classification_is_unknown",
+    class = "some_sec_classif_unknown",
     message = glue(
       "Some `{column}` are unknown:
       {collapse2(unknown)}"
